==> haskell-cryptonite-conduit-0.2.2-47-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cryptonite-conduit.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptonite-conduit
version: 0.2.2
id: cryptonite-conduit-0.2.2-6Fg4Cg3Oloz9PIfnwPU5Rh
key: cryptonite-conduit-0.2.2-6Fg4Cg3Oloz9PIfnwPU5Rh
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: https://github.com/haskell-crypto/cryptonite-conduit
synopsis: cryptonite conduit
description:
    Conduit bridge for cryptonite
    .
    For now only provide a conduit version for hash and hmac, but
    with contribution, this could provide cipher conduits too,
    and probably other things.
category: Cryptography, Conduit
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
indefinite: False
exposed-modules:
    Crypto.Cipher.ChaChaPoly1305.Conduit Crypto.Hash.Conduit
    Crypto.MAC.HMAC.Conduit Crypto.PubKey.ECIES.Conduit
abi: a4e3a94a012c2d05d060ed19b8283781
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/cryptonite-conduit-0.2.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/cryptonite-conduit-0.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/cryptonite-conduit-0.2.2
hs-libraries: HScryptonite-conduit-0.2.2-6Fg4Cg3Oloz9PIfnwPU5Rh
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    conduit-1.2.13-E5VJ8PXbisH7yqxLCGPZk2
    conduit-extra-1.2.3.2-66RG0jtrkdDD0s74YkKINr
    cryptonite-0.24-CpwkoOed0xp5yvbaGvna7I
    exceptions-0.8.3-FtqgxeR4VUg9hGcIqYr2bq
    memory-0.14.16-JXoliazMy4LBu5xxL66kmR
    resourcet-1.1.11-IDQ3BcbOuN3L37hqhCafaF transformers-0.5.2.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             conduit-1.2.13-E5VJ8PXbisH7yqxLCGPZk2=6dd5e62d92a07f6da7d7b5d7ab5b8218
             conduit-extra-1.2.3.2-66RG0jtrkdDD0s74YkKINr=faaa93b8888b821eff3f309c614c5c0d
             cryptonite-0.24-CpwkoOed0xp5yvbaGvna7I=96c7223eb24ebab9c9677bd383f9a0fa
             exceptions-0.8.3-FtqgxeR4VUg9hGcIqYr2bq=349f1b5172af08123dc6c444b05979b3
             memory-0.14.16-JXoliazMy4LBu5xxL66kmR=73bd87255495d2259f63e7f9009bea01
             resourcet-1.1.11-IDQ3BcbOuN3L37hqhCafaF=667b8b7a5336fee7f4683c8cbac39d0c
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
haddock-interfaces: /usr/share/doc/haskell-cryptonite-conduit/html/cryptonite-conduit.haddock
haddock-html: /usr/share/doc/haskell-cryptonite-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cryptonite-conduit-0.2.2-48-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cryptonite-conduit.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptonite-conduit
version: 0.2.2
id: cryptonite-conduit-0.2.2-H1rhDLIOkbY2oUDsag3VQY
key: cryptonite-conduit-0.2.2-H1rhDLIOkbY2oUDsag3VQY
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: https://github.com/haskell-crypto/cryptonite-conduit
synopsis: cryptonite conduit
description:
    Conduit bridge for cryptonite
    .
    For now only provide a conduit version for hash and hmac, but
    with contribution, this could provide cipher conduits too,
    and probably other things.
category: Cryptography, Conduit
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
indefinite: False
exposed-modules:
    Crypto.Cipher.ChaChaPoly1305.Conduit Crypto.Hash.Conduit
    Crypto.MAC.HMAC.Conduit Crypto.PubKey.ECIES.Conduit
abi: b0dc3d811d115e6448e792218b89f132
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/cryptonite-conduit-0.2.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/cryptonite-conduit-0.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/cryptonite-conduit-0.2.2
hs-libraries: HScryptonite-conduit-0.2.2-H1rhDLIOkbY2oUDsag3VQY
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    conduit-1.2.13-KGlTp1YFxNbGMkHuibtdAg
    conduit-extra-1.2.3.2-G578KQ4JWAN4eJFOJU3rLe
    cryptonite-0.24-CpwkoOed0xp5yvbaGvna7I
    exceptions-0.8.3-FtqgxeR4VUg9hGcIqYr2bq
    memory-0.14.16-JXoliazMy4LBu5xxL66kmR
    resourcet-1.1.11-3TsXMCE9bmqJOgo1a6gjl4 transformers-0.5.2.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             conduit-1.2.13-KGlTp1YFxNbGMkHuibtdAg=f28c447a2bec9bcfe4989e0ac67614c0
             conduit-extra-1.2.3.2-G578KQ4JWAN4eJFOJU3rLe=fb21443c7f8ea5a559913c5877818b98
             cryptonite-0.24-CpwkoOed0xp5yvbaGvna7I=96c7223eb24ebab9c9677bd383f9a0fa
             exceptions-0.8.3-FtqgxeR4VUg9hGcIqYr2bq=349f1b5172af08123dc6c444b05979b3
             memory-0.14.16-JXoliazMy4LBu5xxL66kmR=73bd87255495d2259f63e7f9009bea01
             resourcet-1.1.11-3TsXMCE9bmqJOgo1a6gjl4=5d5f7a5bec88091b43d999202511397f
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
haddock-interfaces: /usr/share/doc/haskell-cryptonite-conduit/html/cryptonite-conduit.haddock
haddock-html: /usr/share/doc/haskell-cryptonite-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
